@@ -1,10 +1,10 @@
 package Perinci::CmdLine;
 
-our $DATE = '2015-04-02'; # DATE
-our $VERSION = '1.45'; # VERSION
+our $DATE = '2015-06-11'; # DATE
+our $VERSION = '1.46'; # VERSION
 
 sub new {
-    die "This module is currently empty, for now please use Perinci::CmdLine::{Lite,Classic,Any} instead";
+    die "This module is currently empty, for now please use Perinci::CmdLine::{Lite,Classic,Any} instead. There is also Perinci::CmdLine::Inline.";
 }
 
 1;
@@ -23,7 +23,7 @@ Perinci::CmdLine - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.45 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2015-04-02.
+This document describes version 1.46 of Perinci::CmdLine (from Perl distribution Perinci-CmdLine), released on 2015-06-11.
 
 =head1 DESCRIPTION
 
@@ -31,7 +31,8 @@ This module is currently empty, becase the implementation is currently split
 into L<Perinci::CmdLine::Lite> (for lightweight version) and
 L<Perinci::CmdLine::Classic> (the full but heavier version). There's also
 L<Perinci::CmdLine::Any> that lets you choose between the two dynamically, a la
-Any::Moose.
+Any::Moose. And finally there's also L<Perinci::CmdLine::Inline>, the even more
+lightweight version.
 
 This module exists solely for convenience of linking purposes. In the future the
 two separate implementation might also be reunited.
@@ -46,6 +47,8 @@ L<Perinci::CmdLine::Classic>
 
 L<Perinci::CmdLine::Any>
 
+L<Perinci::CmdLine::Inline>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-CmdLine>.
